@@ -449,6 +449,34 @@ setReplaceMethod(".enabled",
                    return(obj)
                  })
 
+
+## editable -- can the widget be edited
+setMethod("editable",signature(obj="gWidgetRGtk"),
+          function(obj, ...) {
+            return()
+            .editable(obj, obj@toolkit,...)
+          })
+
+setMethod(".editable",
+          signature(toolkit="guiWidgetsToolkitRGtk2",obj="gWidgetRGtk"),
+          function(obj, toolkit, ...) {
+            message("no default editable method")
+          })
+
+## editable<-
+setReplaceMethod("editable",signature(obj="gWidgetRGtk"),
+                 function(obj, ..., value) {
+                   .editable(obj, obj@toolkit,...) <- value
+                   return(obj)
+                 })
+
+setReplaceMethod(".editable", 
+                 signature(toolkit="guiWidgetsToolkitRGtk2",obj="gWidgetRGtk"),
+                 function(obj, toolkit, ..., value) {
+                   message("no default editable<- method")
+                   return(obj)
+                 })
+
 ## focus
 setMethod("focus",signature(obj="gWidgetRGtk"),
           function(obj, ...) {
