@@ -152,7 +152,29 @@ setMethod(".visible<-",
             return(obj)
           })
 
+##' focus will raise window
+##'
+##' @param object gwindow object
+##' @param toolkit name of toolkit
+##' @param ... ignored
+##' @return NULL called for side effect of raising window
+setMethod(".focus",
+          signature(toolkit="guiWidgetsToolkitRGtk2",obj="gWindowRGtk"),
+          function(obj, toolkit, ...) {
+            w <- getBlock(obj)
+            w$present()
+          })
 
+setReplaceMethod(".focus",
+                 signature(toolkit="guiWidgetsToolkitRGtk2",obj="gWindowRGtk"),
+                 function(obj, toolkit, ..., value) {
+                   if(as.logical(value)) {
+                     w <- getBlock(obj)
+                     w$present()
+                   }
+                   return(obj)
+                 })
+                
 setMethod(".size",
           signature(toolkit="guiWidgetsToolkitRGtk2",obj="gWindowRGtk"),
           function(obj, toolkit, ...) {
